import { isParticipate, deleteSchedule, getScheduleDetail, getUserScheduleInTime, uploadPermissions, modifySchedule } from '../../api/request.js'
import { throttle } from './../../utils/utils.js'
import create from 'dd-store'
import exampleStore from '/stores/exampleStore'
create.Page({
  store: exampleStore,
  useAll: true,
  data: {
    // 传给组件list 的所有数据 comListData
    comListData: {
      repeatList: [
        { id: 0, text: '不重复', icon: 'iconicon_cycle', repeatable: 0, recurrenceModel: { model: 'no_repeat' } },
        { id: 1, text: '每天', icon: '', repeatable: 1, recurrenceModel: { model: 'daily', interval: 1, initialTime: `2020-03-23`, terminateTime: `2022-03-23`, weekDayList: null } },
        { id: 2, text: '每周', icon: '', repeatable: 1, recurrenceModel: { model: 'weekly', interval: 1, initialTime: `2020-03-23`, terminateTime: `2022-03-23`, weekDayList: ['MO'] } },
        { id: 3, text: '每周的工作日', icon: '', repeatable: 1, recurrenceModel: { model: 'weekly', interval: 1, initialTime: `2020-03-23`, terminateTime: `2022-03-23`, weekDayList: ['MO', 'TU', 'WE', 'TH', 'FR'] } },
        { id: 4, text: '每月', icon: '', repeatable: 1, recurrenceModel: { model: 'absoluteMonthly', daysOfMonth: ['23'], interval: 1, initialTime: `2020-03-23`, terminateTime: `2022-03-23`, weekDayList: null } }
      ],
      meetingWayList: [
        { id: 0, text: 'Webex meeting', imageUrl: '../../assests/Webex.png', meetingWayModel: { model: 'webex' } },
        { id: 1, text: 'Zoom Meeting', imageUrl: '../../assests/Zoom.png', meetingWayModel: { model: 'zoom' } },
        { id: 2, text: '钉钉', imageUrl: '../../assests/dingding.png', meetingWayModel: { model: 'dingtalk' } }
      ],
      aheadTimesList: [
        { id: -1, text: '不提醒', icon: 'iconicon_cycle' },
        { id: 0, text: '会议开始时提醒', icon: '' },
        { id: 5, text: '提前5分钟提醒', icon: '' },
        { id: 15, text: '提前15分钟提醒', icon: '' },
        { id: 30, text: '提前30分钟提醒', icon: '' },
        { id: 60, text: '提前一小时提醒', icon: '' },
        { id: 120, text: '提前二小时提醒', icon: '' },
        { id: 1440, text: '提前一天提醒', icon: '' },
        { id: 105120, text: '提前一周提醒', icon: '' }
      ],
      multiple: false,
      complete: false,
      aheadTimesListId: [-1],
      comSelectListId: 0,
      meetingWayModelId: null,
      iconType: 'icon'
    },
    // 传给组件 hList 水平排列  所有数据 comHListData
    comHListData: {
      contactData: [
        { id: 0, text: '钉钉联系人', imageUrl: '../../assests/dingContact.png' },
        { id: 1, text: '手动添加邮箱', imageUrl: '../../assests/emailContact.png' }
      ]
    },
    // 传递给组件toast的所有数据
    conToastData: {
      showToast: false
    },
    // 传递给组件selectPopup 的数据
    conSelectPopupData: {
      showSelectPopup: false,
      selectType: 'common',
      editSaveList: [{ text: '仅保存此会议', id: 'only' }, { text: '保存此次及以后会议', id: 'future' }],
      delSheudleList: [{ text: '仅删除此会议', id: 'only' }, { text: '删除此次及以后会议', id: 'future' }],
      participateStatusList: [{ text: '仅参加此次会议', id: 'only' }, { text: '参加所有会议', id: 'all' }],
      noParticipateStatusList: [{ text: '不参加此次会议', id: 'only' }, { text: '不参加所有会议', id: 'all' }]
    },
    title: ``,
    repeatable: 0,
    recurrenceModel: { model: 'no_repeat' },
    isShowRemark: false,
    repeatWeek: ['SU', 'MO', 'TU', 'WE', 'TH', 'FR', 'SA'],
    popupTitle: '会议重复',
    popupShow: false,
    comType: '',
    remark: '',
    comTimeType: '',
    meetingWayModel: null,
    weekList: ['周日', '周一', '周二', '周三', '周四', '周五', '周六'],
    week: '',
    conflictPeople: [],
    isAcrossDay: false,
    scheduleItem: '',
    originalData: new Map(),
    lock: false,
    aheadTimes: [],
    organizer: '',
    editType: '',
    confirmAttendance: null
  },

  showPop() {
    this.setData({
      show: true
    })
  },
  closePop() {
    this.setData({
      show: false
    })
  },
  Complete(data) {
    console.log(data)
    this.closePop();
  },
  onLoad(event) {
    this.reset()
    dd.setNavigationBar({
      title: `会议详情`
    })
    this.setData({
      scheduleItem: JSON.parse(event.scheduleItem),
    })
    this.getDetail()
  },
  // 获取详情
  getDetail() {
    let data = {
      id: this.data.scheduleItem.id,
      scheduleTemplateId: this.data.scheduleItem.scheduleTemplateId,
      planDate: this.data.scheduleItem.planDate
    }
    getScheduleDetail(data).then(res => {
      if (res.data.code === 0) {
        let participatorList = []
        let originUsers = []
        let participatorUserId = []
        let repeatListMap = new Map()
        for (let value of res.data.data.userList) {
          participatorList.push(value.participator)
          participatorUserId.push(value.participator.userId)
          originUsers.push(value.participator)
        }
        for (let item of this.data.comListData.repeatList) {
          if (item.recurrenceModel.recurrenceModel !== 'weekly') {
            repeatListMap.set(item.recurrenceModel.model, item.id)
          }
        }
        this.setData({
          confirmAttendance: res.data.data.confirmAttendance,
          organizer: res.data.data.organizer,
          'comListData.meetingWayModelId': res.data.data.meetingWayModel === null ? null : (res.data.data.meetingWayModel.model === 'dingtalk' ? 2 : (res.data.data.meetingWayModel.model === 'zoom' ? 1 : 0)),
          'scheduleItem.id': res.data.data.id,
          'scheduleItem.groupId': res.data.data.groupId,
          repeatable: res.data.data.repeatable,
          recurrenceModel: res.data.data.repeatable ? { model: res.data.data.recurrenceModel.model, daysOfMonth: res.data.data.recurrenceModel.daysOfMonth, interval: 1, initialTime: res.data.data.recurrenceModel.initialTime, terminateTime: res.data.data.recurrenceModel.terminateTime, weekDayList: res.data.data.recurrenceModel.weekDayList } : { model: 'no_repeat' },
          originalData: res.data.data,
          title: res.data.data.title,
          remark: res.data.data.remark,
          isShowRemark: res.data.data.remark ? true : false,
          week: this.data.weekList[new Date(res.data.data.startTime.replace(/'-'/g, "\/")).getDay()]
        })
        if (res.data.data.repeatable) {
          this.setData({
            'comListData.comSelectListId': res.data.data.recurrenceModel.model === 'weekly' ? (res.data.data.recurrenceModel.weekDayList.length > 1 ? 3 : 2) : repeatListMap.get(res.data.data.recurrenceModel.model),
          })
        }
        this.store.data.originUsers = participatorList
        this.store.data.locationName = res.data.data.location.locationName
        this.store.data.roomId = res.data.data.meetingRoomId < 0 ? '' : res.data.data.meetingRoomId
        this.store.data.startTime = res.data.data.startTime.replace(/'-'/g, "\/")
        this.store.data.endTime = res.data.data.endTime.replace(/'-'/g, "\/")
        this.store.data.participatorList = participatorList
        this.store.data.participatorUserId = participatorUserId
        this.store.data.originUsersId = participatorUserId
        this.update()
        this.conflictPeople()
        console.log(res.data.data)
      }
    })
  },
  // 添加描述
  addRemark() {
    let isShowRemark = !this.data.isShowRemark
    this.setData({
      isShowRemark: isShowRemark
    })
    this.update()

  },
  // 输入框输入事件
  onInput(event) {
    // dd.alert({
    //   content: JSON.stringify(event)
    // })
    switch (event.target.dataset.type) {
      case 'title':
        this.setData({
          title: event.detail.value
        })
        break
      case 'remark':
        this.setData({
          remark: event.detail.value
        })
        break
    }
  },
  // 输入框失去焦点
  onBlur(event) {
    this.setData({
      'conSelectPopupData.selectType': 'common'
    })
    switch (event.target.dataset.type) {
      case 'title':
        if (this.data.repeatable) {
          this.setData({
            'conSelectPopupData.showSelectPopup': true,
            editType: 'title'
          })
        } else {
          this.isChange('title', 'only')
        }
        break
      case 'remark':
        if (this.data.repeatable) {
          this.setData({
            'conSelectPopupData.showSelectPopup': true,
            editType: 'remark'
          })
        } else {
          this.isChange('remark', 'only')
        }
        break
    }
  },
  // 初始化
  reset() {
    this.store.data.roomId = ''
    this.store.data.participatorList = []
    this.store.data.originUsers = []
    this.store.data.originUsersId = []
    this.store.data.participatorList = []
    this.store.data.participatorUserId = []
    this.store.data.locationName = ''
    this.store.data.startTime = this.getTimes()
    this.store.data.endTime = this.getTimes(new Date(this.getTimes()).setMinutes(new Date(this.store.data.startTime).getMinutes() + 120))
    this.update()
    this.resetRepeatList()
    this.acrossDay(this.store.data.startTime, this.store.data.endTime)
  },
  // 跳转下一页
  nextPage(event) {
    switch (event.target.dataset.nextPage) {
      case 'location':
        dd.navigateTo({ url: `./../place/place?scheduleItem=${JSON.stringify(this.data.scheduleItem)}&repeatable= ${this.data.repeatable}` })
        break
      case 'participantsDetail':
        dd.navigateTo({ url: `./../participantsDetail/participantsDetail?scheduleItem=${JSON.stringify(this.data.scheduleItem)}` })
        break
    }
  },
  // 所有的关闭操作
  close(event) {
    switch (event.target.dataset.close) {
      case 'location':
        this.store.data.locationName = ''
        this.store.data.roomId = ''
        this.update()
        break
      case 'meetingWayModel':
        this.setData({
          'comListData.meetingWayModelId': null,
          meetingWayModel: null
        })
    }
  },
  // 关闭popup 点击mark
  closePopup() {
    this.setData({
      popupShow: false
    })
  },
  // 选择循环机制 选择会议方式  选择时间  出现popup弹窗
  showPopup(event) {
    let iconType = ''
    let complete = false
    let multiple = false
    switch (event.currentTarget.dataset.type) {
      case 'meetingWayModel':
        iconType = 'image',
          complete = true
        multiple = false
        break
      case 'repeat':
        iconType = 'icon',
          complete = true,
          multiple = false
        break
      case 'participator':

        break
      case 'time':
        break
      case 'aheadTime':
        iconType = 'icon',
          complete = true,
          multiple = true
        break
    }
    this.setData({
      popupShow: true,
      comType: event.currentTarget.dataset.type,
      'comListData.complete': complete,
      'comListData.iconType': iconType,
      'comListData.multiple': multiple
    })
  },
  resetRepeatList() {
    let index = 0
    let repeatList = []
    for (let value of this.data.comListData.repeatList) {
      if (index) {
        value.recurrenceModel.initialTime = this.store.data.startTime.replace(/\//g, "-").substring(0, 10)
        value.recurrenceModel.terminateTime = this.getTwoYearToday(this.store.data.startTime)
        if (index === 2) {
          value.recurrenceModel.weekDayList = [this.data.repeatWeek[new Date().getDay()]]
        } else if (index === 4) {
          value.recurrenceModel.daysOfMonth = [this.store.data.startTime.replace(/\//g, "-").substring(8, 10)]
        }
      }
      repeatList.push(value)
      index++
    }
    this.setData({
      'comListData.repeatList': repeatList,
      week: this.data.weekList[new Date().getDay()]
    })

  },
  // 选择完comList后的回调 重复 会议方式
  selectComList(event) {
    switch (this.data.comType) {
      case 'meetingWayModel':
        this.setData({
          'comListData.meetingWayModelId': event.currentTarget.dataset.item.id,
          popupShow: false,
          meetingWayModel: this.data.comListData.meetingWayList[event.currentTarget.dataset.item.id].meetingWayModel
        })
        if (this.data.repeatable) {
          this.setData({
            'conSelectPopupData.showSelectPopup': true,
            editType: 'meeting_way'
          })
        } else {
          this.isChange('meeting_way', 'only')
        }
        break;
      case 'repeat':
        this.resetRepeatList()
        this.setData({
          popupShow: false,
          'comListData.comSelectListId': event.currentTarget.dataset.item.id,
          repeatable: event.currentTarget.dataset.item.repeatable,
          recurrenceModel: event.currentTarget.dataset.item.recurrenceModel
        })
        if (this.data.originalData.repeatable) {
          this.setData({
            'conSelectPopupData.showSelectPopup': true,
            editType: 'repeat'
          })
        } else {
          this.isChange('repeat', 'only')
        }
        break;
    }
  },
  // 选择完水平 HList 的回调
  selectComHList(event) {
    console.log(event)
    switch (event.currentTarget.dataset.item.id) {
      case 0:
        this.addParticipator()
        this.setData({
          popupShow: false
        })
        break;
      case 1:
        this.setData({
          popupShow: false
        })
        dd.navigateTo({ url: `./../outLookContact/outLookContact?scheduleItem=${this.data.scheduleItem}` })
        break;
    }
  },
  // 获取两年后的今天
  getTwoYearToday(startTime) {
    let date = new Date(startTime)
    date.setYear(date.getFullYear() + 2)
    let year = date.getFullYear();
    let month = date.getMonth() + 1 < 10 ? '0' + (date.getMonth() + 1) : date.getMonth() + 1;
    let day = date.getDate() < 10 ? '0' + date.getDate() : date.getDate()
    return year + '-' + month + '-' + day
  },
  // 添加参会人
  addParticipator() {
    const _that = this
    let require = []
    let select = []
    let outLookConcat = []
    for (let participator of _that.store.data.participatorList) {
      if (participator.platform === 'outlook') {
        outLookConcat.push(participator)
      }
    }
    if (this.data.organizer === getApp().globalData.userid) {
      select = this.store.data.participatorUserId
      require = [getApp().globalData.userid]
    } else {
      select = []
      require = [...this.store.data.originUsersId]
    }
    select = _that.selectedelRequired(require, select).pickedUsers
    dd.complexChoose({
      title: "选择参会人",            //标题
      multiple: true,            //是否多选
      pickedUsers: select, //已选用户
      requiredUsers: require,            //必选用户（不可取消选中状态）
      responseUserOnly: true,        //返回人，或者返回人和部门
      success: function (res) {
        let participatorList = []
        let participatorUserId = []
        if (_that.data.organizer === getApp().globalData.userid) {
          participatorList.push({ userId: getApp().globalData.userid, username: getApp().globalData.name, headUrl: getApp().globalData.avatar, platform: 'dingtalk' })
          participatorUserId.push(getApp().globalData.userid)
          res.users.forEach((item, index) => {
            participatorList.push({ userId: item.userId, username: item.name, headUrl: item.avatar, platform: 'dingtalk' })
            participatorUserId.push(item.userId)
          })
        } else {
          _that.store.data.originUsers.forEach((item, index) => {
            participatorList.push(item)
            if (item.platform === 'dingtalk') {
              participatorUserId.push(item.userId)
            }
          })
          res.users.forEach((item, index) => {
            participatorList.push({ userId: item.userId, username: item.name, headUrl: item.avatar, platform: 'dingtalk' })
            participatorUserId.push(item.userId)
          })
        }
        participatorList = _that.setArrary(participatorList.concat(outLookConcat))
        participatorUserId = [...new Set(participatorUserId)]
        _that.store.data.participatorList = participatorList
        _that.store.data.participatorUserId = participatorUserId
        _that.update()
        _that.conflictPeople()
        if (_that.data.repeatable) {
          _that.setData({
            'conSelectPopupData.showSelectPopup': true,
            editType: 'operate_user'
          })
        } else {
          _that.isChange('operate_user', 'only')
        }

        // if (true) {
        //   _that.store.data.originUsers = _that.store.data.participatorList
        //   _that.store.data.originUsersId = _that.store.data.participatorUserId
        //   _that.update()
        // } else {
        //   _that.store.data.participatorList = _that.store.data.originUsers
        //   _that.store.data.participatorUserId = _that.store.data.originUsersId
        // }

      },
      fail: function (err) {
      }
    })
  },
  // 数组 去重
  setArrary(arr) {
    let containt = {}
    for (let x of arr) {
      containt['id' + x.userId] = x
    }
    return Object.values(containt)
  },
  // 点击完成
  onComplete(event) {
    this.store.data.startTime = `${event.startTime}:00`
    this.store.data.endTime = `${event.endTime}:00`
    this.update()
    this.acrossDay(this.store.data.startTime, this.store.data.endTime)
    this.setData({
      popupShow: false,
      editType: ''
    })
    if (this.data.repeatable) {
      this.setData({
        'conSelectPopupData.showSelectPopup': true,
        editType: 'modify_time'
      })
    } else {
      this.isChange('modify_time', 'only')
    }
  },
  // 选择会前提醒时间
  selectAheadtimes(event) {
    this.setData({
      aheadTimes: event,
      popupShow: false
    })
    if (this.data.repeatable) {
      this.setData({
        'conSelectPopupData.showSelectPopup': true,
        editType: 'aheadTimes'
      })
    } else {
      this.isChange('aheadTimes', 'only')
    }
  },
  // 保存编辑
  modifySchedule(data) {
    let obj = {
      scheduleId: this.data.scheduleItem.id,
      templateId: this.data.scheduleItem.scheduleTemplateId,
      planDate: this.data.scheduleItem.planDate
    }
    modifySchedule(Object.assign(data, obj)).then(res => {
      if (res.data.code === 0) {
        this.setData({
          originUsers: this.store.data.participatorList
        })
        this.setData({
          'conToastData.showToast': true
        })
      }
    })
  },
  // 获取时间参数
  getTimes(time = new Date()) {
    let date = new Date(time)
    let year = date.getFullYear()
    let month = date.getMonth() + 1 < 10 ? '0' + (date.getMonth() + 1) : date.getMonth() + 1
    let day = date.getDate() < 10 ? '0' + date.getDate() : date.getDate()
    let hour = date.getHours() < 10 ? '0' + date.getHours() : date.getHours()
    let miunutes = date.getMinutes() < 10 ? '0' + date.getMinutes() : date.getMinutes()
    return `${year}/${month}/${day} ${hour}:${miunutes}:00`
  },
  // 是否跨天
  acrossDay(time1, time2) {
    let isAcrossDay = ''
    if (JSON.stringify(this.getTimes(time1).substring(0, 10)) === JSON.stringify(this.getTimes(time2).substring(0, 10))) {
      isAcrossDay = false
    } else {
      isAcrossDay = true
    }
    this.setData({
      isAcrossDay: isAcrossDay
    })
  },
  // 人员冲突
  conflictPeople() {
    let userIds = []
    for (let value of this.store.data.participatorList) {
      userIds.push(value.userId)
    }
    let data = {
      startTime: this.store.data.startTime.replace(/\//g, "-"),
      endTime: this.store.data.endTime.replace(/\//g, "-"),
      userIds: userIds
    }
    getUserScheduleInTime(data).then(res => {
      let conflictPeople = []
      for (let value in res.data.data) {
        if (res.data.data[value].length > 1) {
          conflictPeople.push(value)
        }
      }
      this.setData({
        conflictPeople: conflictPeople
      })
    })
  },
  // 文件上传
  uploadFile() {
    let data = {
      ddUserId: getApp().globalData.userid,
      type: 'add',
      projectName: 'MING_MEETING'
    }
    uploadPermissions(data).then(res => {
      if (res.data.code === 0) {
        const _that = this
        dd.uploadAttachmentToDingTalk({
          image: { multiple: true, compress: true, max: 9, spaceId: res.data.data },
          space: { spaceId: res.data.data, compress: true, isCopy: 1, max: 9 },
          types: ["photo", "camera", "space"],
          success: (res) => {
            dd.navigateTo({ url: `./../uploadFile/uploadFile?scheduleItem=${JSON.stringify(_that.data.scheduleItem)}&upLoadInfo=${encodeURIComponent(JSON.stringify(res))}` })
          },
          fail: (err) => {
          }
        })
      }
    })

  },
  // toast 消失之后的回调
  onToastHidden() {
    this.setData({
      'conToastData.showToast': false
    })
  },
  // onSelectPopup 选择完的回调
  onSelectPopup(event) {
    switch (this.data.conSelectPopupData.selectType) {
      case 'common':
        this.isChange(this.data.editType, event.currentTarget.dataset.item.id)
        break
      case 'noParticipateStatus':
        let data1 = {
          type: event.currentTarget.dataset.item.id,
          templateId: this.data.scheduleItem.scheduleTemplateId,
          planDate: this.data.scheduleItem.planDate,
          value: 0
        }
        isParticipate(data1).then(res => {
          if (res.data.code === 0) {
            this.setData({
              confirmAttendance: 0,
              'conToastData.showToast': true
            })
          }
        })

        break
      case 'participateStatus':
        let data = {
          type: event.currentTarget.dataset.item.id,
          templateId: this.data.scheduleItem.scheduleTemplateId,
          planDate: this.data.scheduleItem.planDate,
          value: 1
        }
        isParticipate(data).then(res => {
          if (res.data.code === 0) {
            this.setData({
              confirmAttendance: 1,
              'conToastData.showToast': true
            })
          }
        })
        break
      case 'delSheudle':
        dd.confirm({
          title: '删除会议',
          content: '确认删除会议吗？',
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          success: (success) => {
            if (!!success.confirm) {
              let data = {
                scheduleId: this.data.scheduleItem.id,
                identify: this.data.organizer === getApp().globalData.userid ? 'major' : 'identify',
                deleteModel: event.currentTarget.dataset.item.id,
                templateId: this.data.scheduleItem.scheduleTemplateId,
                planDate: this.data.scheduleItem.planDate
              }
              deleteSchedule(data).then(res => {
                dd.navigateBack({
                  delta: 1
                })
              })
            }
          }
        })
        break
    }
    this.setData({
      'conSelectPopupData.showSelectPopup': false
    })
  },
  // onSelectPopupCancel 点击取消 
  onSelectPopupCancel() {
    this.setData({
      'conSelectPopupData.showSelectPopup': false
    })
  },
  // 判断数据发生改变 发生改变 请求
  isChange(value, modifyModel) {
    let modifyContent = ''
    switch (value) {
      case 'title':
        let dataTitle = {
          title: this.data.title,
          modifyModel: modifyModel,
          modifyContent: 'title'
        }
        this.modifySchedule(dataTitle)
        break
      case 'remark':
        let dataRemark = {
          remark: this.data.remark,
          modifyModel: modifyModel,
          modifyContent: 'remark'
        }
        this.modifySchedule(dataRemark)
        break
      case 'meeting_way':
        let dataWay = {
          meetingWayModel: this.data.meetingWayModel,
          modifyModel: modifyModel,
          modifyContent: 'meeting_way'
        }
        this.modifySchedule(dataWay)
        break
      case 'operate_user':
        let addUserList = this.arrayPoor(this.store.data.originUsers, this.store.data.participatorList).addUserList
        let deleteUserList = this.arrayPoor(this.store.data.originUsers, this.store.data.participatorList).deleteUserList
        let dataUser = {
          addUserList: addUserList,
          deleteUserList: deleteUserList,
          modifyModel: modifyModel,
          modifyContent: 'operate_user'
        }
        this.modifySchedule(dataUser)
        break
      case 'repeat':
        if (this.data.originalData.repeatable === 0 && this.data.repeatable === 1) {
          let dataRepeat1 = {
            startTime: this.store.data.startTime.replace(/\//g, "-"),
            endTime: this.store.data.endTime.replace(/\//g, "-"),
            modifyModel: modifyModel,
            modifyContent: 'to_repeat',
            recurrenceModel: this.data.recurrenceModel,
            repeatable: this.data.repeatable
          }
          this.modifySchedule(dataRepeat1)
        }
        else if (this.data.originalData.repeatable === 1 && this.data.repeatable === 0) {
          let dataRepeat2 = {
            startTime: this.store.data.startTime.replace(/\//g, "-"),
            endTime: this.store.data.endTime.replace(/\//g, "-"),
            modifyModel: modifyModel,
            modifyContent: 'no_repeat',
            recurrenceModel: this.data.recurrenceModel,
            repeatable: this.data.repeatable
          }
          this.modifySchedule(dataRepeat2)
        }
        else {
          let dataRepeat3 = {
            startTime: this.store.data.startTime.replace(/\//g, "-"),
            endTime: this.store.data.endTime.replace(/\//g, "-"),
            modifyModel: modifyModel,
            modifyContent: 'change_rule',
            recurrenceModel: this.data.recurrenceModel,
            repeatable: this.data.repeatable
          }
          this.modifySchedule(dataRepeat3)
        }
        break
      case 'modify_location':

        break
      case 'modify_time':
        let data = {
          modifyModel: modifyModel,
          startTime: this.store.data.startTime.replace(/\//g, "-"),
          endTime: this.store.data.endTime.replace(/\//g, "-"),
          modifyContent: 'modify_time'
        }
        this.modifySchedule(data)
        break
      case 'aheadTimes':
        debugger
        let dataAheadTimes = {
          modifyModel: modifyModel,
          aheadTimes: this.data.aheadTimes,
          modifyContent: 'aheadTimes'
        }
        this.modifySchedule(dataAheadTimes)
        break
    }
  },
  // 数组取差值 原先的数组与现在的比较 增加与减少
  arrayPoor(origin, now) {
    let originMap = new Map()
    let nowMap = new Map()
    let add = []
    let del = []
    for (let x of origin) {
      originMap.set(x.userId, x)
    }
    for (let x of now) {
      nowMap.set(x.userId, x)
      let status1 = originMap.get(x.userId)
      if (!status1) {
        add.push(x)
      }
    }
    for (let x of origin) {
      let status2 = nowMap.get(x.userId)
      if (!status2) {
        del.push(x)
      }
    }
    return {
      addUserList: add,
      deleteUserList: del
    }
  },
  // 已选用户去中去掉必选用户
  selectedelRequired(req, pic) {
    for (let i = 0; i < req.length; i++) {
      for (let m = 0; m < pic.length; m++) {
        if (req[i] == pic[m]) {
          pic.splice(m, 1)
          m--;
        }
      }
    }
    return {
      requiredUsers: req,
      pickedUsers: pic
    }
  },
  // 删除 日程
  delSheudle() {
    if (this.data.repeatable) {
      this.setData({
        'conSelectPopupData.selectType': 'delSheudle',
        'conSelectPopupData.showSelectPopup': true
      })
    } else {
      dd.confirm({
        title: '删除会议',
        content: '确认删除会议吗？',
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        success: (success) => {
          if (!!success.confirm) {
            let data = {
              scheduleId: this.data.scheduleItem.id,
              identify: this.data.organizer === getApp().globalData.userid ? 'major' : 'identify',
              deleteModel: 'only'
            }
            deleteSchedule(data).then(res => {
              dd.navigateBack({
                delta: 1
              })
            })
          }
        }
      })
    }
  },
  // 点击参加
  participate() {
    let data = {
      scheduleId: this.data.scheduleItem.id,
      value: 1,
      type: 'only'
    }
    if (this.data.repeatable) {
      this.setData({
        'conSelectPopupData.showSelectPopup': true,
        'conSelectPopupData.selectType': 'participateStatus'
      })
    } else {
      isParticipate(data).then(res => {
        if (res.data.code === 0) {
          this.setData({
            confirmAttendance: 1,
            'conToastData.showToast': true
          })
        }
      })
    }
  },
  // 点击 不参加
  noParticipate() {
    let data = {
      scheduleId: this.data.scheduleItem.id,
      value: 0,
      type: 'only'
    }
    if (this.data.repeatable) {
      this.setData({
        'conSelectPopupData.showSelectPopup': true,
        'conSelectPopupData.selectType': 'noParticipateStatus'
      })
    } else {
      isParticipate(data).then(res => {
        if (res.data.code === 0) {
          this.setData({
            confirmAttendance: 0,
            'conToastData.showToast': true
          })
        }
      })
    }
  }

});
